#ifndef CRC_H
#define CRC_H

#include "common_types.h"

uint32 crc32(const char *filename);

#endif
